@@ -9,9 +9,11 @@ import sre_constants
 import subprocess
 from string import Formatter
 
+
 def prefixed_environ():
     return dict((("${}".format(key), value) for key, value in os.environ.iteritems()))
 
+
 def attempt_version_bump(args):
     try:
         regex = re.compile(args.parse)
@@ -50,11 +52,13 @@ def attempt_version_bump(args):
             repr(e.message), repr(parsed)))
         return
 
+
 def main(args=None):
 
     parser1 = argparse.ArgumentParser(add_help=False)
 
-    parser1.add_argument('--config-file', default='.bumpversion.cfg', metavar='FILE',
+    parser1.add_argument(
+        '--config-file', default='.bumpversion.cfg', metavar='FILE',
         help='Config file to read most of the variables from', required=False)
 
     known_args, remaining_argv = parser1.parse_known_args(args)
@@ -74,17 +78,16 @@ def main(args=None):
     parser2.set_defaults(**defaults)
 
     parser2.add_argument('--current-version', metavar='VERSION',
-        help='Version that needs to be updated', required=False)
+                         help='Version that needs to be updated', required=False)
     parser2.add_argument('--bump', metavar='PART',
-        help='Part of the version to be bumped.',
-        default='patch')
+                         help='Part of the version to be bumped.',
+                         default='patch')
     parser2.add_argument('--parse', metavar='REGEX',
-        help='Regex parsing the version string',
-        default='(?P<major>\d+)\.(?P<minor>\d+)\.(?P<patch>\d+)')
+                         help='Regex parsing the version string',
+                         default='(?P<major>\d+)\.(?P<minor>\d+)\.(?P<patch>\d+)')
     parser2.add_argument('--serialize', metavar='FORMAT',
-        help='How to format what is parsed back to a version',
-        default='{major}.{minor}.{patch}')
-
+                         help='How to format what is parsed back to a version',
+                         default='{major}.{minor}.{patch}')
 
     known_args, remaining_argv = parser2.parse_known_args(remaining_argv)
 
@@ -95,29 +98,29 @@ def main(args=None):
         defaults['new_version'] = _attempted_new_version
 
     parser3 = argparse.ArgumentParser(
-      description='Bumps version strings',
-      formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-      conflict_handler='resolve',
-      parents=[parser2],
+        description='Bumps version strings',
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        conflict_handler='resolve',
+        parents=[parser2],
     )
 
     parser3.set_defaults(**defaults)
 
     parser3.add_argument('--current-version', metavar='VERSION',
-        help='Version that needs to be updated',
-        required=not 'current_version' in defaults)
+                         help='Version that needs to be updated',
+                         required=not 'current_version' in defaults)
     parser3.add_argument('--dry-run', '-n', action='store_true',
-        default=False, help="Don't write any files, just pretend.")
+                         default=False, help="Don't write any files, just pretend.")
     parser3.add_argument('--new-version', metavar='VERSION',
-        help='New version that should be in the files',
-        required=not 'new_version' in defaults)
+                         help='New version that should be in the files',
+                         required=not 'new_version' in defaults)
     parser3.add_argument('--commit', action='store_true',
-        help='Create a commit in version control')
+                         help='Create a commit in version control')
     parser3.add_argument('--tag', action='store_true',
-        help='Create a tag in version control')
+                         help='Create a tag in version control')
     parser3.add_argument('--message', '-m', metavar='COMMIT_MSG',
-        help='Commit message',
-        default='Bump version: {current_version} → {new_version}')
+                         help='Commit message',
+                         default='Bump version: {current_version} → {new_version}')
 
     files = []
     if 'files' in defaults:
@@ -125,8 +128,8 @@ def main(args=None):
         files = defaults['files'].split(' ')
 
     parser3.add_argument('files', metavar='file',
-            nargs='+' if len(files) == 0 else '*',
-            help='Files to change', default=files)
+                         nargs='+' if len(files) == 0 else '*',
+                         help='Files to change', default=files)
 
     args = parser3.parse_args(remaining_argv)
 
@@ -136,12 +139,14 @@ def main(args=None):
     if os.path.isdir(".git"):
         lines = [
             line.strip() for line in
-            subprocess.check_output(["git", "status", "--porcelain"]).splitlines()
+            subprocess.check_output(
+                ["git", "status", "--porcelain"]).splitlines()
             if not line.strip().startswith("??")
         ]
 
         if lines:
-            assert False, "Git working directory not clean:\n{}".format("\n".join(lines))
+            assert False, "Git working directory not clean:\n{}".format(
+                "\n".join(lines))
 
     for path in args.files:
         with open(path, 'r') as f:
@@ -156,7 +161,6 @@ def main(args=None):
             with open(path, 'w') as f:
                 f.write(after)
 
-
     commit_files = args.files
 
     if config:
@@ -173,11 +177,13 @@ def main(args=None):
                 subprocess.check_call(["git", "add", path])
 
             formatargs = {
-              "current_version": args.current_version,
-              "new_version": args.new_version,
+                "current_version": args.current_version,
+                "new_version": args.new_version,
             }
             formatargs.update(prefixed_environ())
 
-            subprocess.check_call(["git", "commit", "-m", args.message.format(**formatargs)])
-            subprocess.check_call(["git", "tag", "v{new_version}".format(**formatargs)])
-
+            subprocess.check_call(
+                ["git", "commit", "-m", args.message.format(**formatargs)])
+            if args.tag:
+                subprocess.check_call(
+                    ["git", "tag", "v{new_version}".format(**formatargs)])
